@@ -18,6 +18,7 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * @link       https://www.librenms.org
+ *
  * @copyright  2018 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
  */
@@ -82,6 +83,7 @@ class QueryBuilderParser implements \JsonSerializable
 
     protected $builder;
     protected $schema;
+    private $tables;
 
     private function __construct(array $builder)
     {
@@ -106,7 +108,7 @@ class QueryBuilderParser implements \JsonSerializable
     /**
      * Recursively find tables (including expanding macros) in the given rules
      *
-     * @param array $rules
+     * @param  array  $rules
      * @return array List of tables found in rules
      */
     protected function findTablesRecursive($rules)
@@ -142,7 +144,7 @@ class QueryBuilderParser implements \JsonSerializable
     /**
      * Initialize this from json generated by jQuery QueryBuilder
      *
-     * @param string|array $json
+     * @param  string|array  $json
      * @return static
      */
     public static function fromJson($json)
@@ -157,7 +159,7 @@ class QueryBuilderParser implements \JsonSerializable
     /**
      * Initialize this from a legacy LibreNMS rule
      *
-     * @param string $query
+     * @param  string  $query
      * @return static
      */
     public static function fromOld($query)
@@ -229,7 +231,7 @@ class QueryBuilderParser implements \JsonSerializable
      * Get the SQL for this rule, ready to execute with device_id supplied as the parameter
      * If $expand is false, this will return a more readable representation of the rule, but not executable.
      *
-     * @param bool $expand
+     * @param  bool  $expand
      * @return null|string The rule or null if this is invalid.
      */
     public function toSql($expand = true)
@@ -255,9 +257,9 @@ class QueryBuilderParser implements \JsonSerializable
     /**
      * Parse a rule group
      *
-     * @param $rule
-     * @param bool $expand Expand macros?
-     * @param bool $wrap Wrap in parenthesis
+     * @param  array  $rule
+     * @param  bool  $expand  Expand macros?
+     * @param  bool  $wrap  Wrap in parenthesis
      * @return string
      */
     private function parseGroup($rule, $expand = false, $wrap = true)
@@ -284,8 +286,8 @@ class QueryBuilderParser implements \JsonSerializable
     /**
      * Parse a rule
      *
-     * @param $rule
-     * @param bool $expand Expand macros?
+     * @param  array  $rule
+     * @param  bool  $expand  Expand macros?
      * @return string
      */
     protected function parseRule($rule, $expand = false)
@@ -322,9 +324,9 @@ class QueryBuilderParser implements \JsonSerializable
     /**
      * Expand macro to sql
      *
-     * @param $subject
-     * @param bool $tables_only Used when finding tables in query returns an array instead of sql string
-     * @param int $depth_limit
+     * @param  string  $subject
+     * @param  bool  $tables_only  Used when finding tables in query returns an array instead of sql string
+     * @param  int  $depth_limit
      * @return string|array
      */
     protected function expandMacro($subject, $tables_only = false, $depth_limit = 20)
@@ -367,7 +369,7 @@ class QueryBuilderParser implements \JsonSerializable
     /**
      * Generate glue and first part of sql query for this rule
      *
-     * @param string $target the name of the table to target, for alerting, this should be devices
+     * @param  string  $target  the name of the table to target, for alerting, this should be devices
      * @return array
      */
     protected function generateGlue($target = 'devices')
@@ -395,8 +397,8 @@ class QueryBuilderParser implements \JsonSerializable
     /**
      * Get glue sql between tables. Resolve fields to use.
      *
-     * @param string $parent
-     * @param string $child
+     * @param  string  $parent
+     * @param  string  $child
      * @return string
      */
     public function getGlue($parent, $child)
@@ -457,9 +459,12 @@ class QueryBuilderParser implements \JsonSerializable
 
     /**
      * Specify data which should be serialized to JSON
+     *
      * @link https://php.net/manual/en/jsonserializable.jsonserialize.php
+     *
      * @return mixed data which can be serialized by <b>json_encode</b>,
-     * which is a value of any type other than a resource.
+     *               which is a value of any type other than a resource.
+     *
      * @since 5.4.0
      */
     public function jsonSerialize()
