@@ -39,6 +39,8 @@ use Symfony\Component\Process\Process;
 
 class NetSnmpQuery implements SnmpQueryInterface
 {
+    private const DEFAULT_FLAGS = '-OQXUte';
+
     /**
      * @var array
      */
@@ -80,7 +82,7 @@ class NetSnmpQuery implements SnmpQueryInterface
     /**
      * @var array|string
      */
-    private $options = ['-OQXUte'];
+    private $options = [self::DEFAULT_FLAGS];
     /**
      * @var \App\Models\Device
      */
@@ -130,10 +132,14 @@ class NetSnmpQuery implements SnmpQueryInterface
     /**
      * Set a context for the snmp query
      * This is most commonly used to fetch alternate sets of data, such as different VRFs
+     *
+     * @param  string|null  $v2  Version 2/3 context name
+     * @param  string|null  $v3_prefix  Optional context prefix to prepend for Version 3 queries
+     * @return \LibreNMS\Data\Source\SnmpQueryInterface
      */
-    public function context(string $context): SnmpQueryInterface
+    public function context(?string $v2, ?string $v3_prefix = null): SnmpQueryInterface
     {
-        $this->context = $context;
+        $this->context = ($this->device->snmpver === 'v3' ? $v3_prefix : '') . $v2;
 
         return $this;
     }
@@ -149,6 +155,17 @@ class NetSnmpQuery implements SnmpQueryInterface
         return $this;
     }
 
+    /**
+     * Do not error on out of order indexes.
+     * Use with caution as we could get stuck in an infinite loop.
+     */
+    public function allowUnordered(): SnmpQueryInterface
+    {
+        $this->options = array_merge($this->options, ['-Cc']);
+
+        return $this;
+    }
+
     /**
      * Output all OIDs numerically
      */
@@ -159,6 +176,29 @@ class NetSnmpQuery implements SnmpQueryInterface
         return $this;
     }
 
+    /**
+     * Hide MIB in output
+     */
+    public function hideMib(): SnmpQueryInterface
+    {
+        $this->options = array_merge($this->options, ['-Os']);
+
+        return $this;
+    }
+
+    /**
+     * Output enum values as strings instead of values. This could affect index output.
+     */
+    public function enumStrings(): SnmpQueryInterface
+    {
+        // remove -Oe from the default flags
+        if (isset($this->options[0]) && Str::contains($this->options[0], 'e')) {
+            $this->options[0] = str_replace('e', '', $this->options[0]);
+        }
+
+        return $this;
+    }
+
     /**
      * Set option(s) for net-snmp command line. Overrides the default options.
      * Some options may break parsing, but you can manually parse the raw output if needed.
@@ -173,7 +213,7 @@ class NetSnmpQuery implements SnmpQueryInterface
     {
         $this->options = $options !== null
             ? Arr::wrap($options)
-            : ['-OQXUte'];
+            : [self::DEFAULT_FLAGS];
 
         return $this;
     }
@@ -229,7 +269,7 @@ class NetSnmpQuery implements SnmpQueryInterface
 
     private function buildCli(string $command, array $oids): array
     {
-        $cmd = $this->initCommand($command);
+        $cmd = $this->initCommand($command, $oids);
 
         array_push($cmd, '-M', $this->mibDirectories());
 
@@ -309,9 +349,13 @@ class NetSnmpQuery implements SnmpQueryInterface
         return new SnmpResponse($output, $stderr, $exitCode);
     }
 
-    private function initCommand(string $binary): array
+    private function initCommand(string $binary, array $oids): array
     {
-        if ($binary == 'snmpwalk' && $this->device->snmpver !== 'v1' && ! Config::getOsSetting($this->device->os, 'snmp_bulk', true)) {
+        if ($binary == 'snmpwalk'
+            && $this->device->snmpver !== 'v1'
+            && Config::getOsSetting($this->device->os, 'snmp_bulk', true)
+            && empty(array_intersect($oids, Config::getCombined($this->device->os, 'oids.no_bulk'))) // skip for oids that do not work with bulk
+        ) {
             $snmpcmd = [Config::get('snmpbulkwalk', 'snmpbulkwalk')];
 
             $max_repeaters = $this->device->getAttrib('snmp_max_repeaters') ?: Config::getOsSetting($this->device->os, 'snmp.max_repeaters', Config::get('snmp.max_repeaters', false));
