@@ -18,13 +18,14 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * @link       https://www.librenms.org
+ *
  * @copyright  2019 Tony Murray
  * @author     Tony Murray <murraytony@gmail.com>
  */
 
 namespace App\Facades;
 
-use Auth;
+use Illuminate\Support\Facades\Auth;
 use LibreNMS\Enum\Alert;
 
 class LogManager extends \Illuminate\Log\LogManager
@@ -32,11 +33,11 @@ class LogManager extends \Illuminate\Log\LogManager
     /**
      * Log events to the event table
      *
-     * @param string $text message describing the event
-     * @param \App\Models\Device|int $device device array or device_id
-     * @param string $type brief category for this event. Examples: sensor, state, stp, system, temperature, interface
-     * @param int $severity 1: ok, 2: info, 3: notice, 4: warning, 5: critical, 0: unknown
-     * @param int $reference the id of the referenced entity.  Supported types: interface
+     * @param  string  $text  message describing the event
+     * @param  \App\Models\Device|int  $device  device array or device_id
+     * @param  string  $type  brief category for this event. Examples: sensor, state, stp, system, temperature, interface
+     * @param  int  $severity  1: ok, 2: info, 3: notice, 4: warning, 5: critical, 0: unknown
+     * @param  int  $reference  the id of the referenced entity.  Supported types: interface
      */
     public function event($text, $device = null, $type = null, $severity = Alert::INFO, $reference = null)
     {
