@@ -31,10 +31,11 @@ use App\Models\AuthLog;
 use App\Models\Dashboard;
 use App\Models\User;
 use App\Models\UserPref;
+use Auth;
+use Flasher\Prime\FlasherInterface;
 use Illuminate\Support\Str;
 use LibreNMS\Authentication\LegacyAuth;
 use LibreNMS\Config;
-use Toastr;
 use URL;
 
 class UserController extends Controller
@@ -88,7 +89,7 @@ class UserController extends Controller
      * @param  StoreUserRequest  $request
      * @return \Illuminate\Http\RedirectResponse
      */
-    public function store(StoreUserRequest $request)
+    public function store(StoreUserRequest $request, FlasherInterface $flasher)
     {
         $user = $request->only(['username', 'realname', 'email', 'descr', 'level', 'can_modify_passwd']);
         $user['auth_type'] = LegacyAuth::getType();
@@ -101,12 +102,12 @@ class UserController extends Controller
         $this->updateDashboard($user, $request->get('dashboard'));
 
         if ($user->save()) {
-            Toastr::success(__('User :username created', ['username' => $user->username]));
+            $flasher->addSuccess(__('User :username created', ['username' => $user->username]));
 
             return redirect(route('users.index'));
         }
 
-        Toastr::error(__('Failed to create user'));
+        $flasher->addError(__('Failed to create user'));
 
         return redirect()->back();
     }
@@ -164,29 +165,36 @@ class UserController extends Controller
      * @param  User  $user
      * @return \Illuminate\Http\RedirectResponse
      */
-    public function update(UpdateUserRequest $request, User $user)
+    public function update(UpdateUserRequest $request, User $user, FlasherInterface $flasher)
     {
         if ($request->get('new_password') && $user->canSetPassword($request->user())) {
             $user->setPassword($request->new_password);
+            /** @var User $current_user */
+            $current_user = Auth::user();
+            Auth::setUser($user); // make sure new password is loaded, can only logout other sessions for the active user
+            Auth::logoutOtherDevices($request->new_password);
+
+            // when setting the password on another account, restore back to the user's account.
+            if ($current_user->user_id !== $user->user_id) {
+                Auth::setUser($current_user);
+            }
         }
 
         $user->fill($request->all());
 
         if ($request->has('dashboard') && $this->updateDashboard($user, $request->get('dashboard'))) {
-            Toastr::success(__('Updated dashboard for :username', ['username' => $user->username]));
+            $flasher->addSuccess(__('Updated dashboard for :username', ['username' => $user->username]));
         }
 
-        if ($user->isDirty()) {
-            if ($user->save()) {
-                Toastr::success(__('User :username updated', ['username' => $user->username]));
-            } else {
-                Toastr::error(__('Failed to update user :username', ['username' => $user->username]));
+        if ($user->save()) {
+            $flasher->addSuccess(__('User :username updated', ['username' => $user->username]));
 
-                return redirect()->back();
-            }
+            return redirect(route(Str::contains(URL::previous(), 'preferences') ? 'preferences.index' : 'users.index'));
         }
 
-        return redirect(route(Str::contains(URL::previous(), 'preferences') ? 'preferences.index' : 'users.index'));
+        $flasher->addError(__('Failed to update user :username', ['username' => $user->username]));
+
+        return redirect()->back();
     }
 
     /**
