@@ -18,6 +18,7 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * @link       https://www.librenms.org
+ *
  * @copyright  2016 Neil Lathwood
  * @author     Neil Lathwood <neil@lathwood.co.uk>
  */
@@ -25,6 +26,8 @@
 namespace App\Models;
 
 use Illuminate\Database\Eloquent\Builder;
+use Illuminate\Database\Eloquent\Relations\BelongsToMany;
+use Illuminate\Database\Eloquent\Relations\HasMany;
 use LibreNMS\Enum\AlertState;
 
 class AlertRule extends BaseModel
@@ -34,7 +37,7 @@ class AlertRule extends BaseModel
     // ---- Query scopes ----
 
     /**
-     * @param Builder $query
+     * @param  Builder<AlertRule>  $query
      * @return Builder
      */
     public function scopeEnabled($query)
@@ -45,7 +48,7 @@ class AlertRule extends BaseModel
     /**
      * Scope for only alert rules that are currently in alarm
      *
-     * @param Builder $query
+     * @param  Builder<AlertRule>  $query
      * @return Builder
      */
     public function scopeIsActive($query)
@@ -59,8 +62,8 @@ class AlertRule extends BaseModel
      * Scope to filter rules for devices permitted to user
      * (do not use for admin and global read-only users)
      *
-     * @param $query
-     * @param User $user
+     * @param  Builder<AlertRule>  $query
+     * @param  User  $user
      * @return mixed
      */
     public function scopeHasAccess($query, User $user)
@@ -78,12 +81,12 @@ class AlertRule extends BaseModel
 
     // ---- Define Relationships ----
 
-    public function alerts()
+    public function alerts(): HasMany
     {
         return $this->hasMany(\App\Models\Alert::class, 'rule_id');
     }
 
-    public function devices()
+    public function devices(): BelongsToMany
     {
         return $this->belongsToMany(\App\Models\Device::class, 'alert_device_map', 'device_id', 'device_id');
     }
