@@ -5,6 +5,9 @@ namespace App\Models;
 use DB;
 use Illuminate\Database\Eloquent\Builder;
 use Illuminate\Database\Eloquent\Factories\HasFactory;
+use Illuminate\Database\Eloquent\Relations\BelongsToMany;
+use Illuminate\Database\Eloquent\Relations\HasMany;
+use Illuminate\Database\Eloquent\Relations\MorphMany;
 use Illuminate\Support\Str;
 use LibreNMS\Util\Rewrite;
 use Permissions;
@@ -97,10 +100,18 @@ class Port extends DeviceRelatedModel
         return Rewrite::shortenIfName(Rewrite::normalizeIfName($this->ifName ?: $this->ifDescr));
     }
 
+    /**
+     * Get the description of this port either the parsed description or ifAlias
+     */
+    public function getDescription(): string
+    {
+        return (string) ($this->port_descr_descr ?: $this->ifAlias);
+    }
+
     /**
      * Check if user can access this port.
      *
-     * @param User|int $user
+     * @param  User|int  $user
      * @return bool
      */
     public function canAccess($user)
@@ -130,7 +141,7 @@ class Port extends DeviceRelatedModel
     // ---- Query scopes ----
 
     /**
-     * @param Builder $query
+     * @param  Builder  $query
      * @return Builder
      */
     public function scopeIsDeleted($query)
@@ -141,7 +152,7 @@ class Port extends DeviceRelatedModel
     }
 
     /**
-     * @param Builder $query
+     * @param  Builder  $query
      * @return Builder
      */
     public function scopeIsNotDeleted($query)
@@ -152,7 +163,7 @@ class Port extends DeviceRelatedModel
     }
 
     /**
-     * @param Builder $query
+     * @param  Builder  $query
      * @return Builder
      */
     public function scopeIsUp($query)
@@ -166,7 +177,7 @@ class Port extends DeviceRelatedModel
     }
 
     /**
-     * @param Builder $query
+     * @param  Builder  $query
      * @return Builder
      */
     public function scopeIsDown($query)
@@ -181,7 +192,7 @@ class Port extends DeviceRelatedModel
     }
 
     /**
-     * @param Builder $query
+     * @param  Builder  $query
      * @return Builder
      */
     public function scopeIsShutdown($query)
@@ -195,7 +206,7 @@ class Port extends DeviceRelatedModel
     }
 
     /**
-     * @param Builder $query
+     * @param  Builder  $query
      * @return Builder
      */
     public function scopeIsIgnored($query)
@@ -207,7 +218,7 @@ class Port extends DeviceRelatedModel
     }
 
     /**
-     * @param Builder $query
+     * @param  Builder  $query
      * @return Builder
      */
     public function scopeIsDisabled($query)
@@ -219,7 +230,7 @@ class Port extends DeviceRelatedModel
     }
 
     /**
-     * @param Builder $query
+     * @param  Builder  $query
      * @return Builder
      */
     public function scopeHasErrors($query)
@@ -236,7 +247,7 @@ class Port extends DeviceRelatedModel
     }
 
     /**
-     * @param Builder $query
+     * @param  Builder  $query
      * @return Builder
      */
     public function scopeIsValid($query)
@@ -252,80 +263,94 @@ class Port extends DeviceRelatedModel
         return $this->hasPortAccess($query, $user);
     }
 
+    public function scopeInPortGroup($query, $portGroup)
+    {
+        return $query->whereIn($query->qualifyColumn('port_id'), function ($query) use ($portGroup) {
+            $query->select('port_id')
+                ->from('port_group_port')
+                ->where('port_group_id', $portGroup);
+        });
+    }
+
     // ---- Define Relationships ----
 
-    public function adsl()
+    public function adsl(): HasMany
     {
         return $this->hasMany(PortAdsl::class, 'port_id');
     }
 
-    public function events()
+    public function events(): MorphMany
     {
         return $this->morphMany(Eventlog::class, 'events', 'type', 'reference');
     }
 
-    public function fdbEntries()
+    public function fdbEntries(): HasMany
     {
         return $this->hasMany(\App\Models\PortsFdb::class, 'port_id', 'port_id');
     }
 
-    public function ipv4()
+    public function groups(): BelongsToMany
+    {
+        return $this->belongsToMany(\App\Models\PortGroup::class, 'port_group_port', 'port_id', 'port_group_id');
+    }
+
+    public function ipv4(): HasMany
     {
         return $this->hasMany(\App\Models\Ipv4Address::class, 'port_id');
     }
 
-    public function ipv6()
+    public function ipv6(): HasMany
     {
         return $this->hasMany(\App\Models\Ipv6Address::class, 'port_id');
     }
 
-    public function macAccounting()
+    public function macAccounting(): HasMany
     {
         return $this->hasMany(MacAccounting::class, 'port_id');
     }
 
-    public function macs()
+    public function macs(): HasMany
     {
         return $this->hasMany(Ipv4Mac::class, 'port_id');
     }
 
-    public function nac()
+    public function nac(): HasMany
     {
         return $this->hasMany(PortsNac::class, 'port_id');
     }
 
-    public function ospfNeighbors()
+    public function ospfNeighbors(): HasMany
     {
         return $this->hasMany(OspfNbr::class, 'port_id');
     }
 
-    public function ospfPorts()
+    public function ospfPorts(): HasMany
     {
         return $this->hasMany(OspfPort::class, 'port_id');
     }
 
-    public function pseudowires()
+    public function pseudowires(): HasMany
     {
         return $this->hasMany(Pseudowire::class, 'port_id');
     }
 
-    public function statistics()
+    public function statistics(): HasMany
     {
         return $this->hasMany(PortStatistic::class, 'port_id');
     }
 
-    public function stp()
+    public function stp(): HasMany
     {
         return $this->hasMany(PortStp::class, 'port_id');
     }
 
-    public function users()
+    public function users(): BelongsToMany
     {
         // FIXME does not include global read
         return $this->belongsToMany(\App\Models\User::class, 'ports_perms', 'port_id', 'user_id');
     }
 
-    public function vlans()
+    public function vlans(): HasMany
     {
         return $this->hasMany(PortVlan::class, 'port_id');
     }
