@@ -7,6 +7,9 @@
  *
  * @copyright  (C) 2006 - 2012 Adam Armstrong
  */
+
+use LibreNMS\Util\Debug;
+
 $init_modules = ['web', 'auth'];
 require realpath(__DIR__ . '/..') . '/includes/init.php';
 
@@ -14,10 +17,10 @@ if (! Auth::check()) {
     exit('Unauthorized');
 }
 
-set_debug($_REQUEST['debug']);
+Debug::set($_REQUEST['debug']);
 
 if (is_numeric($_GET['device_id'])) {
-    foreach (dbFetch('SELECT * FROM ports WHERE device_id = ?', [$_GET['device_id']]) as $interface) {
+    foreach (dbFetch('SELECT * FROM ports WHERE device_id = ? ORDER BY portName,ifAlias', [$_GET['device_id']]) as $interface) {
         $interface = cleanPort($interface);
         $string = addslashes(html_entity_decode($interface['label'] . ' - ' . $interface['ifAlias']));
         echo "obj.options[obj.options.length] = new Option('" . $string . "','" . $interface['port_id'] . "');\n";
