@@ -14,7 +14,7 @@ if (! Auth::user()->hasGlobalAdmin()) {
     $status = 'error';
     $message = 'ERROR: You need to be admin to reload Oxidized node list';
 } else {
-    oxidized_reload_nodes();
+    (new \App\ApiClients\Oxidized())->reloadNodes();
     $status = 'ok';
     $message = 'Oxidized node list was reloaded';
 }
