@@ -9,10 +9,10 @@ $printtotal = 0;
 $addarea = 1;
 $transparency = 15;
 
-$rrd_filename = rrd_name($device['hostname'], ['app', 'bind', $app['app_id'], 'cache']);
+$rrd_filename = Rrd::name($device['hostname'], ['app', 'bind', $app['app_id'], 'cache']);
 
 $rrd_list = [];
-if (rrdtool_check_rrd_exists($rrd_filename)) {
+if (Rrd::checkRrdExists($rrd_filename)) {
     $rrd_list[] = [
         'filename' => $rrd_filename,
         'descr'    => 'Mem Exhaustion',
