@@ -12,15 +12,16 @@ $scale_min = 0;
 if (isset($vars['cert_name'])) {
     $cert_name_list = [$vars['cert_name']];
 } else {
-    $cert_name_list = get_arrays_with_application($device, $app_id, $name);
+    $cert_name_list = Rrd::getRrdApplicationArrays($device, $app_id, $name);
 }
 
 $int = 0;
+$rrd_list = [];
 while (isset($cert_name_list[$int])) {
     $cert_name = $cert_name_list[$int];
-    $rrd_filename = rrd_name($device['hostname'], ['app', $name, $app_id, $cert_name]);
+    $rrd_filename = Rrd::name($device['hostname'], ['app', $name, $app_id, $cert_name]);
 
-    if (rrdtool_check_rrd_exists($rrd_filename)) {
+    if (Rrd::checkRrdExists($rrd_filename)) {
         $rrd_list[] = [
             'filename' => $rrd_filename,
             'descr'    => $cert_name,
