@@ -12,8 +12,8 @@ $printtotal = 0;
 $addarea = 1;
 $transparency = 15;
 
-$rrd_filename = rrd_name($device['hostname'], ['app', $app['app_type'], $app['app_id'], $vars['jail']]);
-if (rrdtool_check_rrd_exists($rrd_filename)) {
+$rrd_filename = Rrd::name($device['hostname'], ['app', $app['app_type'], $app['app_id'], $vars['jail']]);
+if (Rrd::checkRrdExists($rrd_filename)) {
     $rrd_list = [
         [
             'filename' => $rrd_filename,
