@@ -9,6 +9,6 @@ $colour_line = '2EAC6D';
 $colour_area_max = 'FFEE99';
 $graph_max = 10000;
 $unit_text = 'Channels';
-$rrd_filename = rrd_name($device['hostname'], ['app', 'freeswitch', 'stats', $app['app_id']]);
+$rrd_filename = Rrd::name($device['hostname'], ['app', 'freeswitch', 'stats', $app['app_id']]);
 
 require 'includes/html/graphs/generic_simplex.inc.php';
