@@ -6,7 +6,7 @@ $scale_min = 0;
 $colours = 'mixed';
 $nototal = (($width < 224) ? 1 : 0);
 $unit_text = 'Packets/sec';
-$rrd_filename = rrd_name($device['hostname'], ['app', 'powerdns', $app['app_id']]);
+$rrd_filename = Rrd::name($device['hostname'], ['app', 'powerdns', $app['app_id']]);
 $array = [
     'q_tcpAnswers' => [
         'descr'  => 'TCP Answers',
@@ -28,7 +28,7 @@ $array = [
 
 $i = 0;
 
-if (rrdtool_check_rrd_exists($rrd_filename)) {
+if (Rrd::checkRrdExists($rrd_filename)) {
     foreach ($array as $ds => $var) {
         $rrd_list[$i]['filename'] = $rrd_filename;
         $rrd_list[$i]['descr'] = $var['descr'];
