@@ -15,10 +15,10 @@ $array = [
     'blocked'   => 'Blocked',
 ];
 
-$rrd_filename = rrd_name($device['hostname'], ['app', 'redis', $app['app_id'], 'clients']);
+$rrd_filename = Rrd::name($device['hostname'], ['app', 'redis', $app['app_id'], 'clients']);
 
 $rrd_list = [];
-if (rrdtool_check_rrd_exists($rrd_filename)) {
+if (Rrd::checkRrdExists($rrd_filename)) {
     $i = 0;
     foreach ($array as $ds => $descr) {
         $rrd_list[$i]['filename'] = $rrd_filename;
