@@ -10,14 +10,14 @@ $bigdescrlen = 20;
 $smalldescrlen = 15;
 $colours = 'mixed';
 
-$rrd_filename = rrd_name($device['hostname'], ['app', 'redis', $app['app_id'], 'commands']);
+$rrd_filename = Rrd::name($device['hostname'], ['app', 'redis', $app['app_id'], 'commands']);
 
 $array = [
     'processed' => 'Processed',
 ];
 
 $rrd_list = [];
-if (rrdtool_check_rrd_exists($rrd_filename)) {
+if (Rrd::checkRrdExists($rrd_filename)) {
     $i = 0;
     foreach ($array as $ds => $descr) {
         $rrd_list[$i]['filename'] = $rrd_filename;
