@@ -12,9 +12,9 @@ $printtotal = 0;
 $addarea = 1;
 $transparency = 15;
 
-$rrd_filename = rrd_name($device['hostname'], ['app', $name, $app_id, $vars['disk']]);
+$rrd_filename = Rrd::name($device['hostname'], ['app', $name, $app_id, $vars['disk']]);
 
-if (rrdtool_check_rrd_exists($rrd_filename)) {
+if (Rrd::checkRrdExists($rrd_filename)) {
     $rrd_list[] = [
         'filename' => $rrd_filename,
         'descr'    => 'Extended',
