@@ -1,6 +1,10 @@
 <?php
 
-$procs = dbFetchRows('SELECT * FROM `processors` where `device_id` = ?', array($device['device_id']));
+$procs = dbFetchRows('SELECT * FROM `processors` where `device_id` = ?', [$device['device_id']]);
+
+if (empty($procs)) {
+    graph_text_and_exit('No Processors');
+}
 
 if (\LibreNMS\Config::getOsSetting($device['os'], 'processor_stacked')) {
     include 'includes/html/graphs/device/processor_stack.inc.php';
