@@ -6,8 +6,8 @@ $rrd_options .= ' -l 0 -E ';
 
 $iter = '1';
 $rrd_options .= " COMMENT:'Toner level            Cur     Min      Max\\n'";
-foreach (dbFetchRows('SELECT * FROM toner where device_id = ?', [$device['device_id']]) as $toner) {
-    $colour = toner2colour($toner['toner_descr'], 100 - $toner['toner_current']);
+foreach (dbFetchRows('SELECT * FROM printer_supplies where device_id = ?', [$device['device_id']]) as $toner) {
+    $colour = toner2colour($toner['supply_descr'], 100 - $toner['supply_current']);
 
     if ($colour['left'] == null) {
         // FIXME generic colour function
@@ -46,15 +46,15 @@ foreach (dbFetchRows('SELECT * FROM toner where device_id = ?', [$device['device
 
     $hostname = gethostbyid($toner['device_id']);
 
-    $descr = safedescr(substr(str_pad($toner['toner_descr'], 16), 0, 16));
-    $rrd_filename = rrd_name($device['hostname'], ['toner', $toner['toner_index']]);
-    $toner_id = $toner['toner_id'];
+    $descr = \LibreNMS\Data\Store\Rrd::safeDescr(substr(str_pad($toner['supply_descr'], 16), 0, 16));
+    $rrd_filename = Rrd::name($device['hostname'], ['toner', $toner['supply_type'], $toner['supply_index']]);
+    $id = $toner['supply_id'];
 
-    $rrd_options .= " DEF:toner$toner_id=$rrd_filename:toner:AVERAGE";
-    $rrd_options .= " LINE2:toner$toner_id#" . $colour['left'] . ":'" . $descr . "'";
-    $rrd_options .= " GPRINT:toner$toner_id:LAST:'%5.0lf%%'";
-    $rrd_options .= " GPRINT:toner$toner_id:MIN:'%5.0lf%%'";
-    $rrd_options .= " GPRINT:toner$toner_id:MAX:%5.0lf%%\l";
+    $rrd_options .= " DEF:toner$id=$rrd_filename:toner:AVERAGE";
+    $rrd_options .= " LINE2:toner$id#" . $colour['left'] . ":'" . $descr . "'";
+    $rrd_options .= " GPRINT:toner$id:LAST:'%5.0lf%%'";
+    $rrd_options .= " GPRINT:toner$id:MIN:'%5.0lf%%'";
+    $rrd_options .= " GPRINT:toner$id:MAX:%5.0lf%%\l";
 
     $iter++;
 }//end foreach
