@@ -11,7 +11,7 @@
  * the source code distribution for details.
  */
 
-$cbqos_parameter_name = "postbits";
-$cbqos_operator = "*";
-$cbqos_operator_param = "8";
-include "includes/html/graphs/port/cbqos_generic.inc.php";
+$cbqos_parameter_name = 'postbits';
+$cbqos_operator = '*';
+$cbqos_operator_param = '8';
+include 'includes/html/graphs/port/cbqos_generic.inc.php';
