@@ -8,6 +8,7 @@ $device_model = Device::find($device['device_id']);
 
 if ($_POST['editing']) {
     if (Auth::user()->hasGlobalAdmin()) {
+        $reload = false;
         if (isset($_POST['parent_id'])) {
             $parents = array_diff((array) $_POST['parent_id'], ['0']);
             // TODO avoid loops!
@@ -27,6 +28,7 @@ if ($_POST['editing']) {
         }
 
         $device_model->override_sysLocation = $override_sysLocation;
+        $device_model->display = empty($_POST['display']) ? null : $_POST['display'];
         $device_model->purpose = $_POST['descr'];
         $device_model->poller_group = $_POST['poller_group'];
         $device_model->ignore = (int) isset($_POST['ignore']);
@@ -39,6 +41,10 @@ if ($_POST['editing']) {
             set_dev_attrib($device, 'override_device_type', true);
         }
 
+        if ($device_model->isDirty('display')) {
+            $reload = true;
+        }
+
         if ($device_model->isDirty()) {
             if ($device_model->save()) {
                 flash()->addSuccess(__('Device record updated'));
@@ -49,15 +55,10 @@ if ($_POST['editing']) {
 
         if (isset($_POST['hostname']) && $_POST['hostname'] !== '' && $_POST['hostname'] !== $device['hostname']) {
             if (Auth::user()->hasGlobalAdmin()) {
-                $result = renamehost($device['device_id'], $_POST['hostname'], 'webui');
+                $result = renamehost($device['device_id'], trim($_POST['hostname']), 'webui');
                 if ($result == '') {
                     flash()->addSuccess("Hostname updated from {$device['hostname']} to {$_POST['hostname']}");
-                    echo '
-                        <script>
-                            var loc = window.location;
-                            window.location.replace(loc.protocol + "//" + loc.host + loc.pathname + loc.search);
-                        </script>
-                    ';
+                    $reload = true;
                 } else {
                     flash()->addError($result . '.  Does your web server have permission to modify the rrd files?');
                 }
@@ -80,6 +81,11 @@ if ($_POST['editing']) {
         if (isset($override_sysContact_string)) {
             set_dev_attrib($device, 'override_sysContact_string', $override_sysContact_string);
         }
+
+        // some changed data not stateful, just reload the page
+        if ($reload) {
+            echo '<script>window.location.reload();</script>';
+        }
     } else {
         include 'includes/html/error-no-perm.inc.php';
     }
@@ -91,7 +97,6 @@ $disable_notify = get_dev_attrib($device, 'disable_notify');
 
 ?>
 
-<h3> Device Settings </h3>
 <div class="row">
     <!-- Bootstrap 3 doesn't support mediaqueries for text aligns (e.g. text-md-left), which makes these buttons stagger on sm or xs screens -->
     <div class="col-md-2 col-md-offset-2">
@@ -119,28 +124,34 @@ $disable_notify = get_dev_attrib($device, 'disable_notify');
 <?php echo csrf_field() ?>
 <input type=hidden name="editing" value="yes">
     <div class="form-group" data-toggle="tooltip" data-container="body" data-placement="bottom" title="Change the hostname used for name resolution" >
-        <label for="edit-hostname-input" class="col-sm-2 control-label" >Hostname:</label>
+        <label for="edit-hostname-input" class="col-sm-2 control-label" >Hostname / IP</label>
         <div class="col-sm-6">
-            <input type="text" id="edit-hostname-input" name="hostname" class="form-control" disabled value=<?php echo \LibreNMS\Util\Clean::html($device['hostname'], []); ?> />
+            <input type="text" id="edit-hostname-input" name="hostname" class="form-control" disabled value="<?php echo htmlentities($device['hostname']); ?>" />
         </div>
         <div class="col-sm-2">
-            <button name="hostname-edit-button" id="hostname-edit-button" class="btn btn-danger"> <i class="fa fa-pencil"></i> </button>
+            <button type="button" name="hostname-edit-button" id="hostname-edit-button" class="btn btn-danger" onclick="toggleHostnameEdit()"> <i class="fa fa-pencil"></i> </button>
+        </div>
+    </div>
+    <div class="form-group" data-toggle="tooltip" data-container="body" data-placement="bottom" title="Display Name for this device.  Keep short. Available placeholders: hostname, sysName, sysName_fallback, ip" >
+        <label for="edit-display-input" class="col-sm-2 control-label" >Display Name</label>
+        <div class="col-sm-6">
+            <input type="text" id="edit-display-input" name="display" class="form-control" placeholder="System Default" value="<?php echo htmlentities($device_model->display); ?>">
         </div>
     </div>
     <div class="form-group" data-toggle="tooltip" data-container="body" data-placement="bottom" title="Use this IP instead of resolved one for polling" >
-        <label for="edit-overwrite_ip-input" class="col-sm-2 control-label" >Overwrite IP:</label>
+        <label for="edit-overwrite_ip-input" class="col-sm-2 control-label text-danger" >Overwrite IP (do not use)</label>
         <div class="col-sm-6">
-            <input type="text" id="edit-overwrite_up-input" name="overwrite_ip" class="form-control" value=<?php echo $device_model->overwrite_ip; ?>>
+            <input type="text" id="edit-overwrite_ip-input" name="overwrite_ip" class="form-control" value="<?php echo htmlentities($device_model->overwrite_ip); ?>">
         </div>
     </div>
      <div class="form-group">
-        <label for="descr" class="col-sm-2 control-label">Description:</label>
+        <label for="descr" class="col-sm-2 control-label">Description</label>
         <div class="col-sm-6">
             <textarea id="descr" name="descr" class="form-control"><?php echo \LibreNMS\Util\Clean::html($device_model->purpose, []); ?></textarea>
         </div>
     </div>
     <div class="form-group">
-        <label for="type" class="col-sm-2 control-label">Type:</label>
+        <label for="type" class="col-sm-2 control-label">Type</label>
         <div class="col-sm-6">
             <select id="type" name="type" class="form-control">
                 <?php
@@ -167,7 +178,7 @@ $disable_notify = get_dev_attrib($device, 'disable_notify');
        </div>
     </div>
     <div class="form-group">
-        <label for="sysLocation" class="col-sm-2 control-label">Override sysLocation:</label>
+        <label for="sysLocation" class="col-sm-2 control-label">Override sysLocation</label>
         <div class="col-sm-6">
           <input onChange="edit.sysLocation.disabled=!edit.override_sysLocation.checked; edit.sysLocation.select()" type="checkbox" name="override_sysLocation" data-size="small"
                 <?php
@@ -185,7 +196,7 @@ $disable_notify = get_dev_attrib($device, 'disable_notify');
                 if (! $device_model->override_sysLocation) {
                     echo ' disabled="1"';
                 }
-                ?> value="<?php echo \LibreNMS\Util\Clean::html($device_model->location, []); ?>" />
+                ?> value="<?php echo htmlentities($device_model->location); ?>" />
         </div>
     </div>
     <div class="form-group">
@@ -210,11 +221,11 @@ $disable_notify = get_dev_attrib($device, 'disable_notify');
         echo ' disabled="1"';
     }
     ?>
-    value="<?php echo $override_sysContact_string; ?>" />
+    value="<?php echo htmlentities($override_sysContact_string); ?>" />
       </div>
     </div>
     <div class="form-group">
-        <label for="parent_id" class="col-sm-2 control-label">This device depends on:</label>
+        <label for="parent_id" class="col-sm-2 control-label">This device depends on</label>
         <div class="col-sm-6">
             <select multiple name="parent_id[]" id="parent_id" class="form-control" style="width: 100%">
                 <?php
@@ -262,7 +273,7 @@ if (\LibreNMS\Config::get('distributed_poller') === true) {
                 }//endif
 ?>
     <div class="form-group">
-        <label for="disabled" class="col-sm-2 control-label">Disable polling and alerting:</label>
+        <label for="disabled" class="col-sm-2 control-label">Disable polling and alerting</label>
         <div class="col-sm-6">
           <input name="disabled" type="checkbox" id="disabled" value="1" data-size="small"
                 <?php
@@ -280,7 +291,7 @@ if (\LibreNMS\Config::get('distributed_poller') === true) {
     </div>
 
     <div class="form-group">
-      <label for="disable_notify" class="col-sm-2 control-label">Disable alerting:</label>
+      <label for="disable_notify" class="col-sm-2 control-label">Disable alerting</label>
       <div class="col-sm-6">
         <input id="disable_notify" type="checkbox" name="disable_notify" data-size="small"
                 <?php
@@ -293,7 +304,7 @@ if (\LibreNMS\Config::get('distributed_poller') === true) {
     <div class="form-group">
         <label for="ignore" class="col-sm-2 control-label" title="Tag device to ignore alerts. Alert checks will still run.
 However, ignore tag can be read in alert rules.
-If `devices.ignore = 0` or `macros.device = 1` condition is is set and ignore alert tag is on, the alert rule won't match.">Ignore alert tag:</label>
+If `devices.ignore = 0` or `macros.device = 1` condition is is set and ignore alert tag is on, the alert rule won't match.">Ignore alert tag</label>
         <div class="col-sm-6">
            <input name="ignore" type="checkbox" id="ignore" value="1" data-size="small"
                 <?php
@@ -354,21 +365,9 @@ If `devices.ignore = 0` or `macros.device = 1` condition is is set and ignore al
             }
         });
     });
-    $('#hostname-edit-button').on("click", function(e) {
-        e.preventDefault();
-        disabled_state = document.getElementById('edit-hostname-input').disabled;
-        if (disabled_state == true) {
-            document.getElementById('edit-hostname-input').disabled = false;
-        } else {
-            document.getElementById('edit-hostname-input').disabled = true;
-        }
-    });
-    $('#sysLocation').on('keypress', function (e) {
-        if(e.keyCode === 13) {
-            e.preventDefault();
-            $('#edit').trigger( "submit" );
-        }
-    });
+    function toggleHostnameEdit() {
+        document.getElementById('edit-hostname-input').disabled = ! document.getElementById('edit-hostname-input').disabled;
+    }
     $('#parent_id').select2({
         width: 'resolve'
     });
