@@ -83,7 +83,7 @@ foreach ($heads as $head => $extra) {
         $icon .= "'";
     }
 
-    echo '<th><a href="' . generate_url(['page'=>'device', 'device'=>$device['device_id'], 'tab'=>'processes', 'order'=>$lhead, 'by'=>$bhead]) . '"><span' . $icon . '>&nbsp;';
+    echo '<th><a href="' . \LibreNMS\Util\Url::generate(['page' => 'device', 'device' => $device['device_id'], 'tab' => 'processes', 'order' => $lhead, 'by' => $bhead]) . '"><span' . $icon . '>&nbsp;';
     if (! empty($extra)) {
         echo "<abbr title='$extra'>$head</abbr>";
     } else {
@@ -98,8 +98,8 @@ echo '</tr></thead><tbody>';
 foreach (dbFetchRows('SELECT * FROM `processes` WHERE `device_id` = ? ORDER BY ' . $order . ' ' . $by, [$device['device_id']]) as $entry) {
     echo '<tr>';
     echo '<td>' . $entry['pid'] . '</td>';
-    echo '<td>' . format_si(($entry['vsz'] * 1024)) . '</td>';
-    echo '<td>' . format_si(($entry['rss'] * 1024)) . '</td>';
+    echo '<td>' . \LibreNMS\Util\Number::formatSi(($entry['vsz'] * 1024), 2, 3, '') . '</td>';
+    echo '<td>' . \LibreNMS\Util\Number::formatSi(($entry['rss'] * 1024), 2, 3, '') . '</td>';
     echo '<td>' . $entry['cputime'] . '</td>';
     echo '<td>' . $entry['user'] . '</td>';
     echo '<td>' . $entry['command'] . '</td>';
