@@ -28,7 +28,7 @@ onclick=\"location.href='device/" . $device['device_id'] . '/port/' . $port['por
  <td valign=top width=350>";
 echo '        <span class=list-large>
               ' . generate_port_link($port, $port['ifIndex'] . '. ' . $port['label']) . '
-           </span><br /><span class=interface-desc>' . display($port['ifAlias']) . '</span>';
+           </span><br /><span class=interface-desc>' . \LibreNMS\Util\Clean::html($port['ifAlias'], []) . '</span>';
 
 if ($port['ifAlias']) {
     echo '<br />';
@@ -54,7 +54,7 @@ $height = '40';
 $from = Config::get('time.day');
 
 echo '</td><td width=135>';
-echo formatRates(($port['ifInOctets_rate'] * 8)) . " <i class='fa fa-arrows-v fa-lg icon-theme' aria-hidden='true'></i> " . formatRates(($port['ifOutOctets_rate'] * 8));
+echo \LibreNMS\Util\Number::formatSi(($port['ifInOctets_rate'] * 8), 2, 3, 'bps') . " <i class='fa fa-arrows-v fa-lg icon-theme' aria-hidden='true'></i> " . \LibreNMS\Util\Number::formatSi(($port['ifOutOctets_rate'] * 8), 2, 3, 'bps');
 echo '<br />';
 $port['graph_type'] = 'port_bits';
 echo generate_port_link(
@@ -64,7 +64,7 @@ echo generate_port_link(
 );
 
 echo '</td><td width=135>';
-echo '' . formatRates($port['adslAturChanCurrTxRate']) . '/' . formatRates($port['adslAtucChanCurrTxRate']);
+echo '' . \LibreNMS\Util\Number::formatSi($port['adslAturChanCurrTxRate'], 2, 3, 'bps') . '/' . \LibreNMS\Util\Number::formatSi($port['adslAtucChanCurrTxRate'], 2, 3, 'bps');
 echo '<br />';
 $port['graph_type'] = 'port_adsl_speed';
 echo generate_port_link(
@@ -74,7 +74,7 @@ echo generate_port_link(
 );
 
 echo '</td><td width=135>';
-echo '' . formatRates($port['adslAturCurrAttainableRate']) . '/' . formatRates($port['adslAtucCurrAttainableRate']);
+echo '' . \LibreNMS\Util\Number::formatSi($port['adslAturCurrAttainableRate'], 2, 3, 'bps') . '/' . \LibreNMS\Util\Number::formatSi($port['adslAtucCurrAttainableRate'], 2, 3, 'bps');
 echo '<br />';
 $port['graph_type'] = 'port_adsl_attainable';
 echo generate_port_link(
