@@ -17,6 +17,6 @@ return [
     'reset' => '您的密码已重置。',
     'sent' => '已经寄送密码重置连结至您的电子邮件信箱。',
     'token' => '此密码重置权仗无效。',
-    'user' => "找不到使用者的电子邮件地址。",
+    'user' => '找不到使用者的电子邮件地址。',
 
 ];
